==> aliyun-python-sdk-dataworks-public-2.0.0.tar.gz: aliyun-python-sdk-dataworks-public-2.0.0/aliyunsdkdataworks_public/request/v20200518/GetMetaTableChangeLogRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class GetMetaTableChangeLogRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetMetaTableChangeLog','dide')
		self.set_method('POST')
		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())


	def get_StartDate(self):
		return self.get_body_params().get('StartDate')

	def set_StartDate(self,StartDate):
		self.add_body_params('StartDate', StartDate)

	def get_PageNumber(self):
		return self.get_body_params().get('PageNumber')

	def set_PageNumber(self,PageNumber):
		self.add_body_params('PageNumber', PageNumber)

	def get_EndDate(self):
		return self.get_body_params().get('EndDate')

	def set_EndDate(self,EndDate):
		self.add_body_params('EndDate', EndDate)

	def get_TableGuid(self):
		return self.get_body_params().get('TableGuid')

	def set_TableGuid(self,TableGuid):
		self.add_body_params('TableGuid', TableGuid)

	def get_ChangeType(self):
		return self.get_body_params().get('ChangeType')

	def set_ChangeType(self,ChangeType):
		self.add_body_params('ChangeType', ChangeType)

	def get_PageSize(self):
		return self.get_body_params().get('PageSize')

	def set_PageSize(self,PageSize):
		self.add_body_params('PageSize', PageSize)

	def get_ObjectType(self):
		return self.get_body_params().get('ObjectType')

	def set_ObjectType(self,ObjectType):
		self.add_body_params('ObjectType', ObjectType)

==> aliyun-python-sdk-dataworks-public-5.0.1.tar.gz: aliyun-python-sdk-dataworks-public-5.0.1/aliyunsdkdataworks_public/request/v20200518/GetMetaTableChangeLogRequest.py <==
# Licensed to the Apache Software Foundation (ASF) under one
# or more contributor license agreements.  See the NOTICE file
# distributed with this work for additional information
# regarding copyright ownership.  The ASF licenses this file
# to you under the Apache License, Version 2.0 (the
# "License"); you may not use this file except in compliance
# with the License.  You may obtain a copy of the License at
#
#
#     http://www.apache.org/licenses/LICENSE-2.0
#
#
# Unless required by applicable law or agreed to in writing,
# software distributed under the License is distributed on an
# "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
# KIND, either express or implied.  See the License for the
# specific language governing permissions and limitations
# under the License.

from aliyunsdkcore.request import RpcRequest
from aliyunsdkdataworks_public.endpoint import endpoint_data

class GetMetaTableChangeLogRequest(RpcRequest):

	def __init__(self):
		RpcRequest.__init__(self, 'dataworks-public', '2020-05-18', 'GetMetaTableChangeLog')
		self.set_method('POST')

		if hasattr(self, "endpoint_map"):
			setattr(self, "endpoint_map", endpoint_data.getEndpointMap())
		if hasattr(self, "endpoint_regional"):
			setattr(self, "endpoint_regional", endpoint_data.getEndpointRegional())

	def get_StartDate(self): # String
		return self.get_body_params().get('StartDate')

	def set_StartDate(self, StartDate):  # String
		self.add_body_params('StartDate', StartDate)
	def get_PageNumber(self): # Integer
		return self.get_body_params().get('PageNumber')

	def set_PageNumber(self, PageNumber):  # Integer
		self.add_body_params('PageNumber', PageNumber)
	def get_EndDate(self): # String
		return self.get_body_params().get('EndDate')

	def set_EndDate(self, EndDate):  # String
		self.add_body_params('EndDate', EndDate)
	def get_TableGuid(self): # String
		return self.get_body_params().get('TableGuid')

	def set_TableGuid(self, TableGuid):  # String
		self.add_body_params('TableGuid', TableGuid)
	def get_ChangeType(self): # String
		return self.get_body_params().get('ChangeType')

	def set_ChangeType(self, ChangeType):  # String
		self.add_body_params('ChangeType', ChangeType)
	def get_PageSize(self): # Integer
		return self.get_body_params().get('PageSize')

	def set_PageSize(self, PageSize):  # Integer
		self.add_body_params('PageSize', PageSize)
	def get_ObjectType(self): # String
		return self.get_body_params().get('ObjectType')

	def set_ObjectType(self, ObjectType):  # String
		self.add_body_params('ObjectType', ObjectType)
